@@ -1,11 +1,9 @@
-import typer
-
+import logging
 import time
 
-import logging
-
-from fluxvault import FluxKeeper, FluxAgent
+import typer
 
+from fluxvault import FluxAgent, FluxKeeper
 
 PREFIX = "FLUXVAULT"
 
@@ -172,17 +170,6 @@ def agent(
     manage_files = manage_files.split(",")
     manage_files = list(filter(None, manage_files))
 
-    params = [
-        bind_address,
-        bind_port,
-        enable_local_fileserver,
-        local_fileserver_port,
-        manage_files,
-        working_dir,
-        whitelist_addresses,
-        disable_authentication,
-    ]
-
     agent = FluxAgent(
         bind_address=bind_address,
         bind_port=bind_port,
@@ -226,6 +213,7 @@ def main(
 
 
 def entrypoint():
+    """Called by console script"""
     app()
 
 
